@@ -30,7 +30,7 @@ Section: non-free/devel
 Priority: optional
 Maintainer: $maintainer_name <$maintainer_email>
 Build-Depends: debhelper (>= 9)${build_depends}
-Standards-Version: 3.9.5
+Standards-Version: 3.9.7
 
 EOF
 }
@@ -70,6 +70,18 @@ j2se_rules() {
     cat << EOF
 #!/usr/bin/make -f
 
+# Exclude libraries that pull in ALSA or OpenGL which are not needed in normal operation
+EXCLUDE_LIBS = \\
+	--exclude=avplugin \\
+	--exclude=fxavcodecplugin \\
+	--exclude=libjsoundalsa.so \\
+EOF
+    for lib in $exlude_libs; do
+        printf '\t--exclude=%s \\\n' "$lib"
+    done
+    cat << EOF
+	\$(NULL)
+
 %:
 	dh \$@
 
@@ -77,10 +89,26 @@ override_dh_compress:
 	dh_compress \$(shell find $j2se_name/man/ -type f ! -name '*.gz' -printf '${jvm_base##/}/%p\n')
 
 override_dh_shlibdeps:
-	dh_shlibdeps --exclude=fxavcodecplugin --exclude=avplugin -l\$(shell find $j2se_name -type f -name '*.so*' -printf '${jvm_base##/}/%h\n' | sort -u | tr '\n' ':' | sed 's/:\$\$//')
+	dh_shlibdeps \$(EXCLUDE_LIBS) -l\$(shell find $j2se_name -type f -name '*.so*' -printf '${jvm_base##/}/%h\n' | sort -u | tr '\n' ':' | sed 's/:\$\$//')
+
+override_dh_strip_nondeterminism:
+	# Disable dh_strip_nondeterminism to speed up the build
 EOF
 }
 
+j2se_doc_rules() {
+    cat << EOF
+#!/usr/bin/make -f
+
+%:
+	dh \$@
+
+override_dh_strip_nondeterminism:
+	# Disable dh_strip_nondeterminism to speed up the build
+EOF
+}
+
+
 j2se_install_scripts() {
     cat > "$debian_dir/postinst" << EOF
 #!/bin/bash
@@ -247,3 +275,37 @@ You can install the package as root with:
 EOF
     fi
 }
+
+# build debian package
+j2se_run() {
+    echo
+    diskfree "$j2se_required_space"
+    read_maintainer_info
+    case "${j2se_arch}" in
+      i586)
+        j2se_debian_arch=i386
+        ;;
+      amd64|x64)
+        j2se_debian_arch=amd64
+        ;;
+    esac
+    j2se_name="$j2se_package-$j2se_debian_arch"
+    local target="$package_dir/$j2se_name"
+    install -d -m 755 "$( dirname "$target" )"
+    extract_bin "$archive_path" "$j2se_expected_min_size" "$target"
+    rm -rf "$target/.systemPrefs"
+    echo "9" > "$debian_dir/compat"
+    j2se_readme > "$debian_dir/README.Debian"
+    j2se_changelog > "$debian_dir/changelog"
+    eval "$j2se_control" > "$debian_dir/control"
+    j2se_copyright > "$debian_dir/copyright"
+    j2se_rules > "$debian_dir/rules"
+    chmod +x "$debian_dir/rules"
+    j2se_install_scripts
+    install -d "$target/debian"
+    j2se_info > "$target/debian/info"
+    eval "$j2se_jinfo" > "$package_dir/.$j2se_name.jinfo"
+    echo ".$j2se_name.jinfo $jvm_base" > "$debian_dir/install"
+    echo "$j2se_name $jvm_base" >> "$debian_dir/install"
+    j2se_build
+}
